# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/acl/acl_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/acl/acl_service.proto\x12\neolymp.acl\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a!eolymp/wellknown/expression.proto\"M\n\nPermission\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x14\n\x0c\x65ntitlements\x18\x04 \x03(\t\"K\n\x14GrantPermissionInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\x12\x14\n\x0c\x65ntitlements\x18\x03 \x03(\t\"\x17\n\x15GrantPermissionOutput\"(\n\x15RevokePermissionInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"\x18\n\x16RevokePermissionOutput\"*\n\x17\x44\x65scribePermissionInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"F\n\x18\x44\x65scribePermissionOutput\x12*\n\npermission\x18\x01 \x01(\x0b\x32\x16.eolymp.acl.Permission\"\x86\x02\n\x14ListPermissionsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x38\n\x07\x66ilters\x18( \x01(\x0b\x32\'.eolymp.acl.ListPermissionsInput.Filter\x1a\x95\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07user_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12.\n\x04role\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"M\n\x15ListPermissionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.acl.Permission\"\x1b\n\x19IntrospectPermissionInput\"H\n\x1aIntrospectPermissionOutput\x12*\n\npermission\x18\x01 \x01(\x0b\x32\x16.eolymp.acl.Permission2\x94\x05\n\nAclService\x12}\n\x0fGrantPermission\x12 .eolymp.acl.GrantPermissionInput\x1a!.eolymp.acl.GrantPermissionOutput\"%\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x10\x1a\x0e/acl/{user_id}\x12\x80\x01\n\x10RevokePermission\x12!.eolymp.acl.RevokePermissionInput\x1a\".eolymp.acl.RevokePermissionOutput\"%\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x10*\x0e/acl/{user_id}\x12\x86\x01\n\x12\x44\x65scribePermission\x12#.eolymp.acl.DescribePermissionInput\x1a$.eolymp.acl.DescribePermissionOutput\"%\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x10\x12\x0e/acl/{user_id}\x12s\n\x0fListPermissions\x12 .eolymp.acl.ListPermissionsInput\x1a!.eolymp.acl.ListPermissionsOutput\"\x1b\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x06\x12\x04/acl\x12\x85\x01\n\x14IntrospectPermission\x12%.eolymp.acl.IntrospectPermissionInput\x1a&.eolymp.acl.IntrospectPermissionOutput\"\x1e\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\t\x12\x07/whoamiB)Z\'github.com/eolymp/go-sdk/eolymp/acl;aclb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.acl.acl_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\'github.com/eolymp/go-sdk/eolymp/acl;acl'
  _ACLSERVICE.methods_by_name['GrantPermission']._options = None
  _ACLSERVICE.methods_by_name['GrantPermission']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\020\032\016/acl/{user_id}'
  _ACLSERVICE.methods_by_name['RevokePermission']._options = None
  _ACLSERVICE.methods_by_name['RevokePermission']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\020*\016/acl/{user_id}'
  _ACLSERVICE.methods_by_name['DescribePermission']._options = None
  _ACLSERVICE.methods_by_name['DescribePermission']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n\024\202\323\344\223\002\020\022\016/acl/{user_id}'
  _ACLSERVICE.methods_by_name['ListPermissions']._options = None
  _ACLSERVICE.methods_by_name['ListPermissions']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n\024\202\323\344\223\002\006\022\004/acl'
  _ACLSERVICE.methods_by_name['IntrospectPermission']._options = None
  _ACLSERVICE.methods_by_name['IntrospectPermission']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n\024\202\323\344\223\002\t\022\007/whoami'
  _PERMISSION._serialized_start=146
  _PERMISSION._serialized_end=223
  _GRANTPERMISSIONINPUT._serialized_start=225
  _GRANTPERMISSIONINPUT._serialized_end=300
  _GRANTPERMISSIONOUTPUT._serialized_start=302
  _GRANTPERMISSIONOUTPUT._serialized_end=325
  _REVOKEPERMISSIONINPUT._serialized_start=327
  _REVOKEPERMISSIONINPUT._serialized_end=367
  _REVOKEPERMISSIONOUTPUT._serialized_start=369
  _REVOKEPERMISSIONOUTPUT._serialized_end=393
  _DESCRIBEPERMISSIONINPUT._serialized_start=395
  _DESCRIBEPERMISSIONINPUT._serialized_end=437
  _DESCRIBEPERMISSIONOUTPUT._serialized_start=439
  _DESCRIBEPERMISSIONOUTPUT._serialized_end=509
  _LISTPERMISSIONSINPUT._serialized_start=512
  _LISTPERMISSIONSINPUT._serialized_end=774
  _LISTPERMISSIONSINPUT_FILTER._serialized_start=625
  _LISTPERMISSIONSINPUT_FILTER._serialized_end=774
  _LISTPERMISSIONSOUTPUT._serialized_start=776
  _LISTPERMISSIONSOUTPUT._serialized_end=853
  _INTROSPECTPERMISSIONINPUT._serialized_start=855
  _INTROSPECTPERMISSIONINPUT._serialized_end=882
  _INTROSPECTPERMISSIONOUTPUT._serialized_start=884
  _INTROSPECTPERMISSIONOUTPUT._serialized_end=956
  _ACLSERVICE._serialized_start=959
  _ACLSERVICE._serialized_end=1619
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/problem_solver.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.atlas import code_template_service_pb2 as eolymp_dot_atlas_dot_code__template__service__pb2
from eolymp.atlas import scoring_service_pb2 as eolymp_dot_atlas_dot_scoring__service__pb2
from eolymp.atlas import statement_service_pb2 as eolymp_dot_atlas_dot_statement__service__pb2
from eolymp.atlas import submission_service_pb2 as eolymp_dot_atlas_dot_submission__service__pb2
from eolymp.atlas import testing_service_pb2 as eolymp_dot_atlas_dot_testing__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!eolymp/atlas/problem_solver.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a(eolymp/atlas/code_template_service.proto\x1a\"eolymp/atlas/scoring_service.proto\x1a$eolymp/atlas/statement_service.proto\x1a%eolymp/atlas/submission_service.proto\x1a\"eolymp/atlas/testing_service.proto2\xe1\t\n\rProblemSolver\x12\x95\x01\n\x0eListStatements\x12!.eolymp.atlas.ListStatementsInput\x1a\".eolymp.atlas.ListStatementsOutput\"<\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\r\x12\x0b/statements\x12\x8d\x01\n\x0cListExamples\x12\x1f.eolymp.atlas.ListExamplesInput\x1a .eolymp.atlas.ListExamplesOutput\":\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0b\x12\t/examples\x12\xa0\x01\n\x10\x43reateSubmission\x12#.eolymp.atlas.CreateSubmissionInput\x1a$.eolymp.atlas.CreateSubmissionOutput\"A\x82\xe3\n\x1a\x8a\xe3\n\x16\x61tlas:submission:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x0e\"\x0c/submissions\x12\x9c\x01\n\x0fListSubmissions\x12\".eolymp.atlas.ListSubmissionsInput\x1a#.eolymp.atlas.ListSubmissionsOutput\"@\x82\xe3\n\x19\x8a\xe3\n\x15\x61tlas:submission:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0e\x12\x0c/submissions\x12\xb5\x01\n\x12\x44\x65scribeSubmission\x12%.eolymp.atlas.DescribeSubmissionInput\x1a&.eolymp.atlas.DescribeSubmissionOutput\"P\x82\xe3\n\x19\x8a\xe3\n\x15\x61tlas:submission:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x1e\x12\x1c/submissions/{submission_id}\x12{\n\x0fWatchSubmission\x12\".eolymp.atlas.WatchSubmissionInput\x1a#.eolymp.atlas.WatchSubmissionOutput\"\x1d\x82\xe3\n\x19\x8a\xe3\n\x15\x61tlas:submission:read0\x01\x12\x8e\x01\n\rDescribeScore\x12 .eolymp.atlas.DescribeScoreInput\x1a!.eolymp.atlas.DescribeScoreOutput\"8\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02\x08\x12\x06/score\x12\x9f\x01\n\x12LookupCodeTemplate\x12%.eolymp.atlas.LookupCodeTemplateInput\x1a&.eolymp.atlas.LookupCodeTemplateOutput\":\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x0b\x12\t/templateB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.problem_solver_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _PROBLEMSOLVER.methods_by_name['ListStatements']._options = None
  _PROBLEMSOLVER.methods_by_name['ListStatements']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\r\022\013/statements'
  _PROBLEMSOLVER.methods_by_name['ListExamples']._options = None
  _PROBLEMSOLVER.methods_by_name['ListExamples']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\013\022\t/examples'
  _PROBLEMSOLVER.methods_by_name['CreateSubmission']._options = None
  _PROBLEMSOLVER.methods_by_name['CreateSubmission']._serialized_options = b'\202\343\n\032\212\343\n\026atlas:submission:write\352\342\n\013\365\342\n\n\327#>\370\342\n\n\202\323\344\223\002\016\"\014/submissions'
  _PROBLEMSOLVER.methods_by_name['ListSubmissions']._options = None
  _PROBLEMSOLVER.methods_by_name['ListSubmissions']._serialized_options = b'\202\343\n\031\212\343\n\025atlas:submission:read\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\016\022\014/submissions'
  _PROBLEMSOLVER.methods_by_name['DescribeSubmission']._options = None
  _PROBLEMSOLVER.methods_by_name['DescribeSubmission']._serialized_options = b'\202\343\n\031\212\343\n\025atlas:submission:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\036\022\034/submissions/{submission_id}'
  _PROBLEMSOLVER.methods_by_name['WatchSubmission']._options = None
  _PROBLEMSOLVER.methods_by_name['WatchSubmission']._serialized_options = b'\202\343\n\031\212\343\n\025atlas:submission:read'
  _PROBLEMSOLVER.methods_by_name['DescribeScore']._options = None
  _PROBLEMSOLVER.methods_by_name['DescribeScore']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\323\344\223\002\010\022\006/score'
  _PROBLEMSOLVER.methods_by_name['LookupCodeTemplate']._options = None
  _PROBLEMSOLVER.methods_by_name['LookupCodeTemplate']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\013\022\t/template'
  _PROBLEMSOLVER._serialized_start=342
  _PROBLEMSOLVER._serialized_end=1591
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/executor/executor.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.executor import job_pb2 as eolymp_dot_executor_dot_job__pb2
from eolymp.executor import language_pb2 as eolymp_dot_executor_dot_language__pb2
from eolymp.executor import runtime_pb2 as eolymp_dot_executor_dot_runtime__pb2
from eolymp.executor import task_pb2 as eolymp_dot_executor_dot_task__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65olymp/executor/executor.proto\x12\x0f\x65olymp.executor\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x19\x65olymp/executor/job.proto\x1a\x1e\x65olymp/executor/language.proto\x1a\x1d\x65olymp/executor/runtime.proto\x1a\x1a\x65olymp/executor/task.proto\x1a!eolymp/wellknown/expression.proto\"Y\n\x0f\x43reateTaskInput\x12#\n\x04task\x18\x01 \x01(\x0b\x32\x15.eolymp.executor.Task\x12!\n\x03job\x18\x02 \x01(\x0b\x32\x14.eolymp.executor.Job\"\x12\n\x10\x43reateTaskOutput\",\n\x15\x44\x65scribeLanguageInput\x12\x13\n\x0blanguage_id\x18\x01 \x01(\t\"E\n\x16\x44\x65scribeLanguageOutput\x12+\n\x08language\x18\x01 \x01(\x0b\x32\x19.eolymp.executor.Language\"\xf0\x01\n\x12ListLanguagesInput\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.executor.ListLanguagesInput.Filter\x1a\x9c\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x02 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x34\n\ndeprecated\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\"?\n\x13ListLanguagesOutput\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.executor.Language\"*\n\x14\x44\x65scribeRuntimeInput\x12\x12\n\nruntime_id\x18\x01 \x01(\t\"B\n\x15\x44\x65scribeRuntimeOutput\x12)\n\x07runtime\x18\x01 \x01(\x0b\x32\x18.eolymp.executor.Runtime\"\xcb\x02\n\x10ListRuntimeInput\x12\x39\n\x07\x66ilters\x18( \x01(\x0b\x32(.eolymp.executor.ListRuntimeInput.Filter\x1a\xfb\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12,\n\x04lang\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07version\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x04 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x34\n\ndeprecated\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\"<\n\x11ListRuntimeOutput\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.executor.Runtime\"/\n\x19\x44\x65scribeCodeTemplateInput\x12\x12\n\nruntime_id\x18\x01 \x01(\t\".\n\x1a\x44\x65scribeCodeTemplateOutput\x12\x10\n\x08template\x18\x01 \x01(\t2\xe7\x07\n\x08\x45xecutor\x12\x63\n\nCreateTask\x12 .eolymp.executor.CreateTaskInput\x1a!.eolymp.executor.CreateTaskOutput\"\x10\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xc8\x01\x12\xb7\x01\n\x10\x44\x65scribeLanguage\x12&.eolymp.executor.DescribeLanguageInput\x1a\'.eolymp.executor.DescribeLanguageOutput\"R\x82\xe3\n\x19\x8a\xe3\n\x15\x65xecutor:runtime:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02\x1f\x12\x1d/exec/languages/{language_id}\x12\xa0\x01\n\rListLanguages\x12#.eolymp.executor.ListLanguagesInput\x1a$.eolymp.executor.ListLanguagesOutput\"D\x82\xe3\n\x19\x8a\xe3\n\x15\x65xecutor:runtime:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02\x11\x12\x0f/exec/languages\x12\xb1\x01\n\x0f\x44\x65scribeRuntime\x12%.eolymp.executor.DescribeRuntimeInput\x1a&.eolymp.executor.DescribeRuntimeOutput\"O\x82\xe3\n\x19\x8a\xe3\n\x15\x65xecutor:runtime:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02\x1c\x12\x1a/exec/runtime/{runtime_id}\x12\x98\x01\n\x0bListRuntime\x12!.eolymp.executor.ListRuntimeInput\x1a\".eolymp.executor.ListRuntimeOutput\"B\x82\xe3\n\x19\x8a\xe3\n\x15\x65xecutor:runtime:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02\x0f\x12\r/exec/runtime\x12\xc9\x01\n\x14\x44\x65scribeCodeTemplate\x12*.eolymp.executor.DescribeCodeTemplateInput\x1a+.eolymp.executor.DescribeCodeTemplateOutput\"X\x82\xe3\n\x19\x8a\xe3\n\x15\x65xecutor:runtime:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02%\x12#/exec/runtime/{runtime_id}/templateB3Z1github.com/eolymp/go-sdk/eolymp/executor;executorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.executor.executor_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/executor;executor'
  _EXECUTOR.methods_by_name['CreateTask']._options = None
  _EXECUTOR.methods_by_name['CreateTask']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\310\001'
  _EXECUTOR.methods_by_name['DescribeLanguage']._options = None
  _EXECUTOR.methods_by_name['DescribeLanguage']._serialized_options = b'\202\343\n\031\212\343\n\025executor:runtime:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\310\001\202\323\344\223\002\037\022\035/exec/languages/{language_id}'
  _EXECUTOR.methods_by_name['ListLanguages']._options = None
  _EXECUTOR.methods_by_name['ListLanguages']._serialized_options = b'\202\343\n\031\212\343\n\025executor:runtime:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\310\001\202\323\344\223\002\021\022\017/exec/languages'
  _EXECUTOR.methods_by_name['DescribeRuntime']._options = None
  _EXECUTOR.methods_by_name['DescribeRuntime']._serialized_options = b'\202\343\n\031\212\343\n\025executor:runtime:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\310\001\202\323\344\223\002\034\022\032/exec/runtime/{runtime_id}'
  _EXECUTOR.methods_by_name['ListRuntime']._options = None
  _EXECUTOR.methods_by_name['ListRuntime']._serialized_options = b'\202\343\n\031\212\343\n\025executor:runtime:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\310\001\202\323\344\223\002\017\022\r/exec/runtime'
  _EXECUTOR.methods_by_name['DescribeCodeTemplate']._options = None
  _EXECUTOR.methods_by_name['DescribeCodeTemplate']._serialized_options = b'\202\343\n\031\212\343\n\025executor:runtime:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\310\001\202\323\344\223\002%\022#/exec/runtime/{runtime_id}/template'
  _CREATETASKINPUT._serialized_start=303
  _CREATETASKINPUT._serialized_end=392
  _CREATETASKOUTPUT._serialized_start=394
  _CREATETASKOUTPUT._serialized_end=412
  _DESCRIBELANGUAGEINPUT._serialized_start=414
  _DESCRIBELANGUAGEINPUT._serialized_end=458
  _DESCRIBELANGUAGEOUTPUT._serialized_start=460
  _DESCRIBELANGUAGEOUTPUT._serialized_end=529
  _LISTLANGUAGESINPUT._serialized_start=532
  _LISTLANGUAGESINPUT._serialized_end=772
  _LISTLANGUAGESINPUT_FILTER._serialized_start=616
  _LISTLANGUAGESINPUT_FILTER._serialized_end=772
  _LISTLANGUAGESOUTPUT._serialized_start=774
  _LISTLANGUAGESOUTPUT._serialized_end=837
  _DESCRIBERUNTIMEINPUT._serialized_start=839
  _DESCRIBERUNTIMEINPUT._serialized_end=881
  _DESCRIBERUNTIMEOUTPUT._serialized_start=883
  _DESCRIBERUNTIMEOUTPUT._serialized_end=949
  _LISTRUNTIMEINPUT._serialized_start=952
  _LISTRUNTIMEINPUT._serialized_end=1283
  _LISTRUNTIMEINPUT_FILTER._serialized_start=1032
  _LISTRUNTIMEINPUT_FILTER._serialized_end=1283
  _LISTRUNTIMEOUTPUT._serialized_start=1285
  _LISTRUNTIMEOUTPUT._serialized_end=1345
  _DESCRIBECODETEMPLATEINPUT._serialized_start=1347
  _DESCRIBECODETEMPLATEINPUT._serialized_end=1394
  _DESCRIBECODETEMPLATEOUTPUT._serialized_start=1396
  _DESCRIBECODETEMPLATEOUTPUT._serialized_end=1442
  _EXECUTOR._serialized_start=1445
  _EXECUTOR._serialized_end=2444
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/entry_problem.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!eolymp/course/entry_problem.proto\x12\reolymp.course\"\x1e\n\x07Problem\x12\x13\n\x0bproblem_url\x18\x01 \x01(\tB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.entry_problem_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _PROBLEM._serialized_start=52
  _PROBLEM._serialized_end=82
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/testing_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!eolymp/atlas/testing_config.proto\x12\x0c\x65olymp.atlas\"\"\n\rTestingConfig\x12\x11\n\trun_count\x18\x01 \x01(\rB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.testing_config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _TESTINGCONFIG._serialized_start=51
  _TESTINGCONFIG._serialized_end=85
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/problem.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import endpoint_pb2 as eolymp_dot_annotations_dot_endpoint__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/atlas/problem.proto\x12\x0c\x65olymp.atlas\x1a!eolymp/annotations/endpoint.proto\"\xac\x04\n\x07Problem\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x03url\x18\xaa\x05 \x01(\t\x12\x30\n\x05links\x18\xab\x05 \x03(\x0b\x32 .eolymp.atlas.Problem.LinksEntry\x12\x0e\n\x06number\x18\n \x01(\x05\x12\x0f\n\x07visible\x18\x0b \x01(\x08\x12\x0f\n\x07private\x18\x0c \x01(\x08\x12\x0e\n\x06origin\x18\r \x01(\t\x12\x0e\n\x06topics\x18\x14 \x03(\t\x12\x12\n\ndifficulty\x18\x15 \x01(\r\x1a,\n\nLinksEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01:\xc0\x02\xda\xe3\n\xbb\x02\x12\x17\n\x15\x65olymp.acl.AclService\x12\x1b\n\x19\x65olymp.atlas.AssetService\x12 \n\x1e\x65olymp.atlas.AttachmentService\x12\"\n eolymp.atlas.CodeTemplateService\x12\x1d\n\x1b\x65olymp.atlas.ProblemService\x12\x1d\n\x1b\x65olymp.atlas.ScoringService\x12\x1f\n\x1d\x65olymp.atlas.StatementService\x12 \n\x1e\x65olymp.atlas.SubmissionService\x12\x1d\n\x1b\x65olymp.atlas.TestingService\x12\x1d\n\x1b\x65olymp.worker.WorkerServiceB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.problem_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _PROBLEM_LINKSENTRY._options = None
  _PROBLEM_LINKSENTRY._serialized_options = b'8\001'
  _PROBLEM._options = None
  _PROBLEM._serialized_options = b'\332\343\n\273\002\022\027\n\025eolymp.acl.AclService\022\033\n\031eolymp.atlas.AssetService\022 \n\036eolymp.atlas.AttachmentService\022\"\n eolymp.atlas.CodeTemplateService\022\035\n\033eolymp.atlas.ProblemService\022\035\n\033eolymp.atlas.ScoringService\022\037\n\035eolymp.atlas.StatementService\022 \n\036eolymp.atlas.SubmissionService\022\035\n\033eolymp.atlas.TestingService\022\035\n\033eolymp.worker.WorkerService'
  _PROBLEM._serialized_start=80
  _PROBLEM._serialized_end=636
  _PROBLEM_LINKSENTRY._serialized_start=269
  _PROBLEM_LINKSENTRY._serialized_end=313
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/asset_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/atlas/asset_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\"\x81\x01\n\x0fUploadFileInput\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0c\x63hecksum_md5\x18\n \x01(\t\x12\x15\n\rchecksum_sha1\x18\x0b \x01(\t\x12\x17\n\x0f\x63hecksum_sha256\x18\x0c \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x64 \x01(\x0c\"#\n\x10UploadFileOutput\x12\x0f\n\x07\x66ile_id\x18\x02 \x01(\t\"7\n\x19StartMultipartUploadInput\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"/\n\x1aStartMultipartUploadOutput\x12\x11\n\tupload_id\x18\x01 \x01(\t\"G\n\x0fUploadPartInput\x12\x11\n\tupload_id\x18\x01 \x01(\t\x12\x13\n\x0bpart_number\x18\x02 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x64 \x01(\x0c\" \n\x10UploadPartOutput\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\"\xdd\x01\n\x1c\x43ompleteMultipartUploadInput\x12\x11\n\tupload_id\x18\x01 \x01(\t\x12>\n\x05parts\x18\n \x03(\x0b\x32/.eolymp.atlas.CompleteMultipartUploadInput.Part\x1aj\n\x04Part\x12\x0e\n\x06number\x18\x01 \x01(\r\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\x14\n\x0c\x63hecksum_md5\x18\n \x01(\t\x12\x15\n\rchecksum_sha1\x18\x0b \x01(\t\x12\x17\n\x0f\x63hecksum_sha256\x18\x0c \x01(\t\"0\n\x1d\x43ompleteMultipartUploadOutput\x12\x0f\n\x07\x66ile_id\x18\x02 \x01(\t2\x99\x05\n\x0c\x41ssetService\x12\x87\x01\n\nUploadFile\x12\x1d.eolymp.atlas.UploadFileInput\x1a\x1e.eolymp.atlas.UploadFileOutput\":\x82\xe3\n\x14\x8a\xe3\n\x10\x61tlas:file:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\r\"\x0b/data/files\x12\xa7\x01\n\x14StartMultipartUpload\x12\'.eolymp.atlas.StartMultipartUploadInput\x1a(.eolymp.atlas.StartMultipartUploadOutput\"<\x82\xe3\n\x14\x8a\xe3\n\x10\x61tlas:file:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0f\x1a\r/data/uploads\x12\x95\x01\n\nUploadPart\x12\x1d.eolymp.atlas.UploadPartInput\x1a\x1e.eolymp.atlas.UploadPartOutput\"H\x82\xe3\n\x14\x8a\xe3\n\x10\x61tlas:file:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x1b\"\x19/data/uploads/{upload_id}\x12\xbc\x01\n\x17\x43ompleteMultipartUpload\x12*.eolymp.atlas.CompleteMultipartUploadInput\x1a+.eolymp.atlas.CompleteMultipartUploadOutput\"H\x82\xe3\n\x14\x8a\xe3\n\x10\x61tlas:file:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x1b\x1a\x19/data/uploads/{upload_id}B-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.asset_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _ASSETSERVICE.methods_by_name['UploadFile']._options = None
  _ASSETSERVICE.methods_by_name['UploadFile']._serialized_options = b'\202\343\n\024\212\343\n\020atlas:file:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\r\"\013/data/files'
  _ASSETSERVICE.methods_by_name['StartMultipartUpload']._options = None
  _ASSETSERVICE.methods_by_name['StartMultipartUpload']._serialized_options = b'\202\343\n\024\212\343\n\020atlas:file:write\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\017\032\r/data/uploads'
  _ASSETSERVICE.methods_by_name['UploadPart']._options = None
  _ASSETSERVICE.methods_by_name['UploadPart']._serialized_options = b'\202\343\n\024\212\343\n\020atlas:file:write\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\033\"\031/data/uploads/{upload_id}'
  _ASSETSERVICE.methods_by_name['CompleteMultipartUpload']._options = None
  _ASSETSERVICE.methods_by_name['CompleteMultipartUpload']._serialized_options = b'\202\343\n\024\212\343\n\020atlas:file:write\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\033\032\031/data/uploads/{upload_id}'
  _UPLOADFILEINPUT._serialized_start=150
  _UPLOADFILEINPUT._serialized_end=279
  _UPLOADFILEOUTPUT._serialized_start=281
  _UPLOADFILEOUTPUT._serialized_end=316
  _STARTMULTIPARTUPLOADINPUT._serialized_start=318
  _STARTMULTIPARTUPLOADINPUT._serialized_end=373
  _STARTMULTIPARTUPLOADOUTPUT._serialized_start=375
  _STARTMULTIPARTUPLOADOUTPUT._serialized_end=422
  _UPLOADPARTINPUT._serialized_start=424
  _UPLOADPARTINPUT._serialized_end=495
  _UPLOADPARTOUTPUT._serialized_start=497
  _UPLOADPARTOUTPUT._serialized_end=529
  _COMPLETEMULTIPARTUPLOADINPUT._serialized_start=532
  _COMPLETEMULTIPARTUPLOADINPUT._serialized_end=753
  _COMPLETEMULTIPARTUPLOADINPUT_PART._serialized_start=647
  _COMPLETEMULTIPARTUPLOADINPUT_PART._serialized_end=753
  _COMPLETEMULTIPARTUPLOADOUTPUT._serialized_start=755
  _COMPLETEMULTIPARTUPLOADOUTPUT._serialized_end=803
  _ASSETSERVICE._serialized_start=806
  _ASSETSERVICE._serialized_end=1471
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.community import attribute_pb2 as _attribute_pb2
from eolymp.community import member_pb2 as _member_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CompleteRecoverInput(_message.Message):
    __slots__ = ["code", "member_id", "password"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    code: str
    member_id: str
    password: str
    def __init__(self, code: _Optional[str] = ..., password: _Optional[str] = ..., member_id: _Optional[str] = ...) -> None: ...

class CompleteRecoverOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class CompleteVerificationInput(_message.Message):
    __slots__ = ["code", "member_id"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    code: str
    member_id: str
    def __init__(self, code: _Optional[str] = ..., member_id: _Optional[str] = ...) -> None: ...

class CompleteVerificationOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class CreateAccountInput(_message.Message):
    __slots__ = ["captcha", "member"]
    CAPTCHA_FIELD_NUMBER: _ClassVar[int]
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    captcha: str
    member: _member_pb2.Member
    def __init__(self, member: _Optional[_Union[_member_pb2.Member, _Mapping]] = ..., captcha: _Optional[str] = ...) -> None: ...

class CreateAccountOutput(_message.Message):
    __slots__ = ["hint", "member_id"]
    HINT_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    hint: str
    member_id: str
    def __init__(self, member_id: _Optional[str] = ..., hint: _Optional[str] = ...) -> None: ...

class DeleteAccountInput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeleteAccountOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeAccountInput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeAccountOutput(_message.Message):
    __slots__ = ["member", "team"]
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    TEAM_FIELD_NUMBER: _ClassVar[int]
    member: _member_pb2.Member
    team: _member_pb2.Member
    def __init__(self, member: _Optional[_Union[_member_pb2.Member, _Mapping]] = ..., team: _Optional[_Union[_member_pb2.Member, _Mapping]] = ...) -> None: ...

class ResendVerificationInput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ResendVerificationOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class StartRecoveryInput(_message.Message):
    __slots__ = ["captcha", "email", "locale"]
    CAPTCHA_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    captcha: str
    email: str
    locale: str
    def __init__(self, email: _Optional[str] = ..., locale: _Optional[str] = ..., captcha: _Optional[str] = ...) -> None: ...

class StartRecoveryOutput(_message.Message):
    __slots__ = ["hint", "member_id"]
    HINT_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    hint: str
    member_id: str
    def __init__(self, hint: _Optional[str] = ..., member_id: _Optional[str] = ...) -> None: ...

class UpdateAccountInput(_message.Message):
    __slots__ = ["current_password", "member", "patch"]
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ALL: UpdateAccountInput.Patch
    ATTRIBUTES: UpdateAccountInput.Patch
    CURRENT_PASSWORD_FIELD_NUMBER: _ClassVar[int]
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    PATCH_FIELD_NUMBER: _ClassVar[int]
    USER_BIRTHDAY: UpdateAccountInput.Patch
    USER_CITY: UpdateAccountInput.Patch
    USER_COUNTRY: UpdateAccountInput.Patch
    USER_EMAIL: UpdateAccountInput.Patch
    USER_NAME: UpdateAccountInput.Patch
    USER_NICKNAME: UpdateAccountInput.Patch
    USER_PASSWORD: UpdateAccountInput.Patch
    USER_PICTURE: UpdateAccountInput.Patch
    USER_PREFERENCES: UpdateAccountInput.Patch
    USER_PREFERENCES_LOCALE: UpdateAccountInput.Patch
    USER_PREFERENCES_RUNTIME: UpdateAccountInput.Patch
    USER_PREFERENCES_TIMEZONE: UpdateAccountInput.Patch
    current_password: str
    member: _member_pb2.Member
    patch: _containers.RepeatedScalarFieldContainer[UpdateAccountInput.Patch]
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateAccountInput.Patch, str]]] = ..., current_password: _Optional[str] = ..., member: _Optional[_Union[_member_pb2.Member, _Mapping]] = ...) -> None: ...

class UpdateAccountOutput(_message.Message):
    __slots__ = ["hint"]
    HINT_FIELD_NUMBER: _ClassVar[int]
    hint: str
    def __init__(self, hint: _Optional[str] = ...) -> None: ...

class UploadPictureInput(_message.Message):
    __slots__ = ["data", "filename", "offset_x", "offset_y", "size"]
    DATA_FIELD_NUMBER: _ClassVar[int]
    FILENAME_FIELD_NUMBER: _ClassVar[int]
    OFFSET_X_FIELD_NUMBER: _ClassVar[int]
    OFFSET_Y_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    filename: str
    offset_x: int
    offset_y: int
    size: int
    def __init__(self, filename: _Optional[str] = ..., data: _Optional[bytes] = ..., offset_x: _Optional[int] = ..., offset_y: _Optional[int] = ..., size: _Optional[int] = ...) -> None: ...

class UploadPictureOutput(_message.Message):
    __slots__ = ["picture_url"]
    PICTURE_URL_FIELD_NUMBER: _ClassVar[int]
    picture_url: str
    def __init__(self, picture_url: _Optional[str] = ...) -> None: ...



from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Section(_message.Message):
    __slots__ = ["description", "image"]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    IMAGE_FIELD_NUMBER: _ClassVar[int]
    description: _content_pb2.Content
    image: str
    def __init__(self, image: _Optional[str] = ..., description: _Optional[_Union[_content_pb2.Content, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/account_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.community import attribute_pb2 as eolymp_dot_community_dot_attribute__pb2
from eolymp.community import member_pb2 as eolymp_dot_community_dot_member__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&eolymp/community/account_service.proto\x12\x10\x65olymp.community\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a eolymp/community/attribute.proto\x1a\x1d\x65olymp/community/member.proto\"O\n\x12\x43reateAccountInput\x12(\n\x06member\x18\x01 \x01(\x0b\x32\x18.eolymp.community.Member\x12\x0f\n\x07\x63\x61ptcha\x18\x64 \x01(\t\"6\n\x13\x43reateAccountOutput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x0c\n\x04hint\x18\x64 \x01(\t\"\x16\n\x14\x44\x65scribeAccountInput\"i\n\x15\x44\x65scribeAccountOutput\x12(\n\x06member\x18\x01 \x01(\x0b\x32\x18.eolymp.community.Member\x12&\n\x04team\x18\x02 \x01(\x0b\x32\x18.eolymp.community.Member\"\xb5\x03\n\x12UpdateAccountInput\x12\x39\n\x05patch\x18\x01 \x03(\x0e\x32*.eolymp.community.UpdateAccountInput.Patch\x12\x18\n\x10\x63urrent_password\x18\x02 \x01(\t\x12(\n\x06member\x18\n \x01(\x0b\x32\x18.eolymp.community.Member\"\x9f\x02\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x11\n\rUSER_NICKNAME\x10\x65\x12\x0e\n\nUSER_EMAIL\x10\x66\x12\x11\n\rUSER_PASSWORD\x10g\x12\r\n\tUSER_NAME\x10h\x12\x10\n\x0cUSER_PICTURE\x10i\x12\x11\n\rUSER_BIRTHDAY\x10j\x12\x10\n\x0cUSER_COUNTRY\x10k\x12\r\n\tUSER_CITY\x10l\x12\x14\n\x10USER_PREFERENCES\x10m\x12\x1c\n\x17USER_PREFERENCES_LOCALE\x10\xbe\x01\x12\x1e\n\x19USER_PREFERENCES_TIMEZONE\x10\xbf\x01\x12\x1d\n\x18USER_PREFERENCES_RUNTIME\x10\xc0\x01\x12\x0f\n\nATTRIBUTES\x10\x84\x07\"#\n\x13UpdateAccountOutput\x12\x0c\n\x04hint\x18\x01 \x01(\t\"f\n\x12UploadPictureInput\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x10\n\x08offset_x\x18\n \x01(\r\x12\x10\n\x08offset_y\x18\x0b \x01(\r\x12\x0c\n\x04size\x18\x0c \x01(\r\"*\n\x13UploadPictureOutput\x12\x13\n\x0bpicture_url\x18\x01 \x01(\t\"\x14\n\x12\x44\x65leteAccountInput\"\x15\n\x13\x44\x65leteAccountOutput\"\x19\n\x17ResendVerificationInput\"\x1a\n\x18ResendVerificationOutput\"<\n\x19\x43ompleteVerificationInput\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x02 \x01(\t\"\x1c\n\x1a\x43ompleteVerificationOutput\"D\n\x12StartRecoveryInput\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x02 \x01(\t\x12\x0f\n\x07\x63\x61ptcha\x18\x64 \x01(\t\"6\n\x13StartRecoveryOutput\x12\x0c\n\x04hint\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x02 \x01(\t\"I\n\x14\x43ompleteRecoverInput\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x11\n\tmember_id\x18\x03 \x01(\t\"\x17\n\x15\x43ompleteRecoverOutput2\x91\n\n\x0e\x41\x63\x63ountService\x12}\n\rCreateAccount\x12$.eolymp.community.CreateAccountInput\x1a%.eolymp.community.CreateAccountOutput\"\x1f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\n\"\x08/account\x12\x83\x01\n\x0f\x44\x65scribeAccount\x12&.eolymp.community.DescribeAccountInput\x1a\'.eolymp.community.DescribeAccountOutput\"\x1f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\n\x12\x08/account\x12}\n\rUpdateAccount\x12$.eolymp.community.UpdateAccountInput\x1a%.eolymp.community.UpdateAccountOutput\"\x1f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\n\x1a\x08/account\x12\x85\x01\n\rUploadPicture\x12$.eolymp.community.UploadPictureInput\x1a%.eolymp.community.UploadPictureOutput\"\'\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x12\"\x10/account/picture\x12}\n\rDeleteAccount\x12$.eolymp.community.DeleteAccountInput\x1a%.eolymp.community.DeleteAccountOutput\"\x1f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\n*\x08/account\x12\xa0\x01\n\x12ResendVerification\x12).eolymp.community.ResendVerificationInput\x1a*.eolymp.community.ResendVerificationOutput\"3\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e\"\x1c/account/verification/resend\x12\xa8\x01\n\x14\x43ompleteVerification\x12+.eolymp.community.CompleteVerificationInput\x1a,.eolymp.community.CompleteVerificationOutput\"5\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x01\x82\xd3\xe4\x93\x02 \"\x1e/account/verification/complete\x12\x8c\x01\n\rStartRecovery\x12$.eolymp.community.StartRecoveryInput\x1a%.eolymp.community.StartRecoveryOutput\".\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x19\"\x17/account/recovery/start\x12\x96\x01\n\x10\x43ompleteRecovery\x12&.eolymp.community.CompleteRecoverInput\x1a\'.eolymp.community.CompleteRecoverOutput\"1\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x1c\"\x1a/account/recovery/completeB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.account_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _ACCOUNTSERVICE.methods_by_name['CreateAccount']._options = None
  _ACCOUNTSERVICE.methods_by_name['CreateAccount']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\n\"\010/account'
  _ACCOUNTSERVICE.methods_by_name['DescribeAccount']._options = None
  _ACCOUNTSERVICE.methods_by_name['DescribeAccount']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\n\022\010/account'
  _ACCOUNTSERVICE.methods_by_name['UpdateAccount']._options = None
  _ACCOUNTSERVICE.methods_by_name['UpdateAccount']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\n\032\010/account'
  _ACCOUNTSERVICE.methods_by_name['UploadPicture']._options = None
  _ACCOUNTSERVICE.methods_by_name['UploadPicture']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\022\"\020/account/picture'
  _ACCOUNTSERVICE.methods_by_name['DeleteAccount']._options = None
  _ACCOUNTSERVICE.methods_by_name['DeleteAccount']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\n*\010/account'
  _ACCOUNTSERVICE.methods_by_name['ResendVerification']._options = None
  _ACCOUNTSERVICE.methods_by_name['ResendVerification']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\036\"\034/account/verification/resend'
  _ACCOUNTSERVICE.methods_by_name['CompleteVerification']._options = None
  _ACCOUNTSERVICE.methods_by_name['CompleteVerification']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\001\202\323\344\223\002 \"\036/account/verification/complete'
  _ACCOUNTSERVICE.methods_by_name['StartRecovery']._options = None
  _ACCOUNTSERVICE.methods_by_name['StartRecovery']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\005\202\323\344\223\002\031\"\027/account/recovery/start'
  _ACCOUNTSERVICE.methods_by_name['CompleteRecovery']._options = None
  _ACCOUNTSERVICE.methods_by_name['CompleteRecovery']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\034\"\032/account/recovery/complete'
  _CREATEACCOUNTINPUT._serialized_start=192
  _CREATEACCOUNTINPUT._serialized_end=271
  _CREATEACCOUNTOUTPUT._serialized_start=273
  _CREATEACCOUNTOUTPUT._serialized_end=327
  _DESCRIBEACCOUNTINPUT._serialized_start=329
  _DESCRIBEACCOUNTINPUT._serialized_end=351
  _DESCRIBEACCOUNTOUTPUT._serialized_start=353
  _DESCRIBEACCOUNTOUTPUT._serialized_end=458
  _UPDATEACCOUNTINPUT._serialized_start=461
  _UPDATEACCOUNTINPUT._serialized_end=898
  _UPDATEACCOUNTINPUT_PATCH._serialized_start=611
  _UPDATEACCOUNTINPUT_PATCH._serialized_end=898
  _UPDATEACCOUNTOUTPUT._serialized_start=900
  _UPDATEACCOUNTOUTPUT._serialized_end=935
  _UPLOADPICTUREINPUT._serialized_start=937
  _UPLOADPICTUREINPUT._serialized_end=1039
  _UPLOADPICTUREOUTPUT._serialized_start=1041
  _UPLOADPICTUREOUTPUT._serialized_end=1083
  _DELETEACCOUNTINPUT._serialized_start=1085
  _DELETEACCOUNTINPUT._serialized_end=1105
  _DELETEACCOUNTOUTPUT._serialized_start=1107
  _DELETEACCOUNTOUTPUT._serialized_end=1128
  _RESENDVERIFICATIONINPUT._serialized_start=1130
  _RESENDVERIFICATIONINPUT._serialized_end=1155
  _RESENDVERIFICATIONOUTPUT._serialized_start=1157
  _RESENDVERIFICATIONOUTPUT._serialized_end=1183
  _COMPLETEVERIFICATIONINPUT._serialized_start=1185
  _COMPLETEVERIFICATIONINPUT._serialized_end=1245
  _COMPLETEVERIFICATIONOUTPUT._serialized_start=1247
  _COMPLETEVERIFICATIONOUTPUT._serialized_end=1275
  _STARTRECOVERYINPUT._serialized_start=1277
  _STARTRECOVERYINPUT._serialized_end=1345
  _STARTRECOVERYOUTPUT._serialized_start=1347
  _STARTRECOVERYOUTPUT._serialized_end=1401
  _COMPLETERECOVERINPUT._serialized_start=1403
  _COMPLETERECOVERINPUT._serialized_end=1476
  _COMPLETERECOVEROUTPUT._serialized_start=1478
  _COMPLETERECOVEROUTPUT._serialized_end=1501
  _ACCOUNTSERVICE._serialized_start=1504
  _ACCOUNTSERVICE._serialized_end=2801
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Project(_message.Message):
    __slots__ = ["home_url", "id", "logo_url", "name", "url"]
    HOME_URL_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    LOGO_URL_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    home_url: str
    id: str
    logo_url: str
    name: str
    url: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., url: _Optional[str] = ..., logo_url: _Optional[str] = ..., home_url: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/bookmark_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#eolymp/atlas/bookmark_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\"8\n\x10SetBookmarkInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x10\n\x08\x62ookmark\x18\x02 \x01(\x08\"\x13\n\x11SetBookmarkOutput\"&\n\x10GetBookmarkInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"%\n\x11GetBookmarkOutput\x12\x10\n\x08\x62ookmark\x18\x01 \x01(\x08\x32\xf5\x01\n\x0f\x42ookmarkService\x12p\n\x0bGetBookmark\x12\x1e.eolymp.atlas.GetBookmarkInput\x1a\x1f.eolymp.atlas.GetBookmarkOutput\" \xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xc8\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0b\x12\t/bookmark\x12p\n\x0bSetBookmark\x12\x1e.eolymp.atlas.SetBookmarkInput\x1a\x1f.eolymp.atlas.SetBookmarkOutput\" \xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x0b\"\t/bookmarkB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.bookmark_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _BOOKMARKSERVICE.methods_by_name['GetBookmark']._options = None
  _BOOKMARKSERVICE.methods_by_name['GetBookmark']._serialized_options = b'\352\342\n\013\365\342\n\000\000\310A\370\342\nd\202\323\344\223\002\013\022\t/bookmark'
  _BOOKMARKSERVICE.methods_by_name['SetBookmark']._options = None
  _BOOKMARKSERVICE.methods_by_name['SetBookmark']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\013\"\t/bookmark'
  _SETBOOKMARKINPUT._serialized_start=120
  _SETBOOKMARKINPUT._serialized_end=176
  _SETBOOKMARKOUTPUT._serialized_start=178
  _SETBOOKMARKOUTPUT._serialized_end=197
  _GETBOOKMARKINPUT._serialized_start=199
  _GETBOOKMARKINPUT._serialized_end=237
  _GETBOOKMARKOUTPUT._serialized_start=239
  _GETBOOKMARKOUTPUT._serialized_end=276
  _BOOKMARKSERVICE._serialized_start=279
  _BOOKMARKSERVICE._serialized_end=524
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/course_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.course import course_pb2 as eolymp_dot_course_dot_course__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/course/course_service.proto\x12\reolymp.course\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1a\x65olymp/course/course.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"\xa0\x03\n\x10ListCoursesInput\x12\x0e\n\x06render\x18\x01 \x01(\x08\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x37\n\x07\x66ilters\x18( \x01(\x0b\x32&.eolymp.course.ListCoursesInput.Filter\x12\x36\n\x04sort\x18\x32 \x01(\x0e\x32(.eolymp.course.ListCoursesInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x1a\xa7\x01\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\n \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x08topic_id\x18\x0b \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06locale\x18\x0c \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"\x17\n\x08Sortable\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\"H\n\x11ListCoursesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12$\n\x05items\x18\x02 \x03(\x0b\x32\x15.eolymp.course.Course\"8\n\x13\x44\x65scribeCourseInput\x12\x11\n\tcourse_id\x18\x01 \x01(\t\x12\x0e\n\x06render\x18\x02 \x01(\x08\"=\n\x14\x44\x65scribeCourseOutput\x12%\n\x06\x63ourse\x18\x01 \x01(\x0b\x32\x15.eolymp.course.Course\":\n\x11\x43reateCourseInput\x12%\n\x06\x63ourse\x18\x01 \x01(\x0b\x32\x15.eolymp.course.Course\"\'\n\x12\x43reateCourseOutput\x12\x11\n\tcourse_id\x18\x01 \x01(\t\"\xf2\x01\n\x11UpdateCourseInput\x12\x35\n\x05patch\x18\x01 \x03(\x0e\x32&.eolymp.course.UpdateCourseInput.Patch\x12\x11\n\tcourse_id\x18\x02 \x01(\t\x12%\n\x06\x63ourse\x18\x03 \x01(\x0b\x32\x15.eolymp.course.Course\"l\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\n\n\x06LOCALE\x10\x01\x12\x08\n\x04NAME\x10\x02\x12\x0f\n\x0b\x44\x45SCRIPTION\x10\x03\x12\t\n\x05IMAGE\x10\x04\x12\x0e\n\nVISIBILITY\x10\x05\x12\x0c\n\x08\x44URATION\x10\x06\x12\n\n\x06TOPICS\x10\x07\"\x14\n\x12UpdateCourseOutput\"&\n\x11\x44\x65leteCourseInput\x12\x11\n\tcourse_id\x18\x01 \x01(\t\"\x14\n\x12\x44\x65leteCourseOutput2\x8e\x06\n\rCourseService\x12\x8f\x01\n\x0c\x43reateCourse\x12 .eolymp.course.CreateCourseInput\x1a!.eolymp.course.CreateCourseOutput\":\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\n\x1a\x08/courses\x12\x9b\x01\n\x0cUpdateCourse\x12 .eolymp.course.UpdateCourseInput\x1a!.eolymp.course.UpdateCourseOutput\"F\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x16\x1a\x14/courses/{course_id}\x12\x9b\x01\n\x0c\x44\x65leteCourse\x12 .eolymp.course.DeleteCourseInput\x1a!.eolymp.course.DeleteCourseOutput\"F\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x16*\x14/courses/{course_id}\x12\xa0\x01\n\x0e\x44\x65scribeCourse\x12\".eolymp.course.DescribeCourseInput\x1a#.eolymp.course.DescribeCourseOutput\"E\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x16\x12\x14/courses/{course_id}\x12\x8b\x01\n\x0bListCourses\x12\x1f.eolymp.course.ListCoursesInput\x1a .eolymp.course.ListCoursesOutput\"9\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\n\x12\x08/coursesB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.course_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _COURSESERVICE.methods_by_name['CreateCourse']._options = None
  _COURSESERVICE.methods_by_name['CreateCourse']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\n\032\010/courses'
  _COURSESERVICE.methods_by_name['UpdateCourse']._options = None
  _COURSESERVICE.methods_by_name['UpdateCourse']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\026\032\024/courses/{course_id}'
  _COURSESERVICE.methods_by_name['DeleteCourse']._options = None
  _COURSESERVICE.methods_by_name['DeleteCourse']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\026*\024/courses/{course_id}'
  _COURSESERVICE.methods_by_name['DescribeCourse']._options = None
  _COURSESERVICE.methods_by_name['DescribeCourse']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\026\022\024/courses/{course_id}'
  _COURSESERVICE.methods_by_name['ListCourses']._options = None
  _COURSESERVICE.methods_by_name['ListCourses']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\n\022\010/courses'
  _LISTCOURSESINPUT._serialized_start=250
  _LISTCOURSESINPUT._serialized_end=666
  _LISTCOURSESINPUT_FILTER._serialized_start=474
  _LISTCOURSESINPUT_FILTER._serialized_end=641
  _LISTCOURSESINPUT_SORTABLE._serialized_start=643
  _LISTCOURSESINPUT_SORTABLE._serialized_end=666
  _LISTCOURSESOUTPUT._serialized_start=668
  _LISTCOURSESOUTPUT._serialized_end=740
  _DESCRIBECOURSEINPUT._serialized_start=742
  _DESCRIBECOURSEINPUT._serialized_end=798
  _DESCRIBECOURSEOUTPUT._serialized_start=800
  _DESCRIBECOURSEOUTPUT._serialized_end=861
  _CREATECOURSEINPUT._serialized_start=863
  _CREATECOURSEINPUT._serialized_end=921
  _CREATECOURSEOUTPUT._serialized_start=923
  _CREATECOURSEOUTPUT._serialized_end=962
  _UPDATECOURSEINPUT._serialized_start=965
  _UPDATECOURSEINPUT._serialized_end=1207
  _UPDATECOURSEINPUT_PATCH._serialized_start=1099
  _UPDATECOURSEINPUT_PATCH._serialized_end=1207
  _UPDATECOURSEOUTPUT._serialized_start=1209
  _UPDATECOURSEOUTPUT._serialized_end=1229
  _DELETECOURSEINPUT._serialized_start=1231
  _DELETECOURSEINPUT._serialized_end=1269
  _DELETECOURSEOUTPUT._serialized_start=1271
  _DELETECOURSEOUTPUT._serialized_end=1291
  _COURSESERVICE._serialized_start=1294
  _COURSESERVICE._serialized_end=2076
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/executor/job.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.executor import task_pb2 as eolymp_dot_executor_dot_task__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x65olymp/executor/job.proto\x12\x0f\x65olymp.executor\x1a\x1a\x65olymp/executor/task.proto\"\xde\x0f\n\x03Job\x12\x11\n\treference\x18\x01 \x01(\t\x12\x0e\n\x06origin\x18\x02 \x01(\t\x12\x39\n\rpreconditions\x18\n \x03(\x0b\x32\".eolymp.executor.Task.Precondition\x12*\n\x06\x61\x63tors\x18\x14 \x03(\x0b\x32\x1a.eolymp.executor.Job.Actor\x12+\n\x08scenario\x18( \x03(\x0b\x32\x19.eolymp.executor.Job.Step\x12&\n\x04runs\x18\x1e \x03(\x0b\x32\x18.eolymp.executor.Job.Run\x1a\xc4\x03\n\x05\x41\x63tor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07runtime\x18\n \x01(\t\x12\x12\n\nsource_ern\x18\x0b \x01(\t\x12\x12\n\nheader_ern\x18\x0c \x01(\t\x12\x12\n\nfooter_ern\x18\r \x01(\t\x12\x12\n\nsource_url\x18\x0e \x01(\t\x12\x12\n\nheader_url\x18\x0f \x01(\t\x12\x12\n\nfooter_url\x18\x10 \x01(\t\x12\x30\n\x03\x65nv\x18( \x03(\x0b\x32#.eolymp.executor.Job.Actor.EnvEntry\x12(\n\x05\x66iles\x18) \x03(\x0b\x32\x19.eolymp.executor.Job.File\x12>\n\routput_format\x18# \x01(\x0e\x32\'.eolymp.executor.Job.Actor.OutputFormat\x12)\n\x05mount\x18\x32 \x03(\x0b\x32\x1a.eolymp.executor.Job.Mount\x1a*\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"1\n\x0cOutputFormat\x12\r\n\tEXIT_CODE\x10\x00\x12\x12\n\x0eTESTLIB_OUTPUT\x10\x01\x1a,\n\x05Mount\x12\x12\n\nfrom_actor\x18\x01 \x01(\t\x12\x0f\n\x07to_path\x18\x02 \x01(\t\x1a<\n\x04\x46ile\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x12\n\nsource_ern\x18\x02 \x01(\t\x12\x12\n\nsource_url\x18\x03 \x01(\t\x1a\x61\n\x03Run\x12\x11\n\treference\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\r\x12\x0e\n\x06labels\x18\n \x03(\t\x12(\n\x05steps\x18\x14 \x03(\x0b\x32\x19.eolymp.executor.Job.Step\x1a\xe1\x08\n\x04Step\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x0f\x65ven_on_failure\x18\x64 \x01(\x08\x12\x17\n\x0fonly_on_failure\x18\x65 \x01(\x08\x12\x30\n\x05write\x18\n \x01(\x0b\x32\x1f.eolymp.executor.Job.Step.WriteH\x00\x12.\n\x04\x63opy\x18\x0b \x01(\x0b\x32\x1e.eolymp.executor.Job.Step.CopyH\x00\x12\x34\n\x07\x65xecute\x18\x0c \x01(\x0b\x32!.eolymp.executor.Job.Step.ExecuteH\x00\x12\x32\n\x06upload\x18\r \x01(\x0b\x32 .eolymp.executor.Job.Step.UploadH\x00\x12\x30\n\x05group\x18\x0e \x01(\x0b\x32\x1f.eolymp.executor.Job.Step.GroupH\x00\x1al\n\x05Write\x12\x12\n\nsource_ern\x18\x01 \x01(\t\x12\x12\n\nsource_url\x18\x05 \x01(\t\x12\x14\n\x0ctarget_actor\x18\x02 \x01(\t\x12\x13\n\x0btarget_path\x18\x03 \x01(\t\x12\x10\n\x08\x66ix_crlf\x18\x04 \x01(\x08\x1a\xa8\x01\n\x06Upload\x12\x14\n\x0csource_actor\x18\x01 \x01(\t\x12\x13\n\x0bsource_path\x18\x02 \x01(\t\x12\x13\n\x0btarget_name\x18\x03 \x01(\t\x12\x12\n\noptionally\x18\x04 \x01(\x08\x12\x0b\n\x03ttl\x18\x05 \x01(\r\x12\x10\n\x08max_size\x18\x06 \x01(\r\x12\x15\n\rmax_data_size\x18\x07 \x01(\r\x12\x14\n\x0c\x66orce_upload\x18\x08 \x01(\x08\x1a\x87\x01\n\x04\x43opy\x12\x14\n\x0csource_actor\x18\x01 \x01(\t\x12\x13\n\x0bsource_path\x18\x02 \x01(\t\x12\x14\n\x0ctarget_actor\x18\x03 \x01(\t\x12\x13\n\x0btarget_path\x18\x04 \x01(\t\x12\x12\n\noptionally\x18\x05 \x01(\x08\x12\x15\n\rremove_source\x18\x06 \x01(\x08\x1a\xae\x02\n\x07\x45xecute\x12\r\n\x05\x61\x63tor\x18\x01 \x01(\t\x12\x0c\n\x04\x61rgs\x18\x02 \x03(\t\x12\x37\n\x03\x65nv\x18\x03 \x03(\x0b\x32*.eolymp.executor.Job.Step.Execute.EnvEntry\x12\r\n\x05stdin\x18\x1e \x01(\t\x12\x0e\n\x06stdout\x18\x1f \x01(\t\x12\x0e\n\x06stderr\x18  \x01(\t\x12\x12\n\nstdin_last\x18! \x01(\x08\x12\x17\n\x0fwall_time_limit\x18\n \x01(\r\x12\x16\n\x0e\x63pu_time_limit\x18\x0b \x01(\r\x12\x14\n\x0cmemory_limit\x18\x0c \x01(\x04\x12\x17\n\x0f\x66ile_size_limit\x18\r \x01(\x04\x1a*\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a=\n\x05Group\x12\x34\n\tprocesses\x18\x01 \x03(\x0b\x32!.eolymp.executor.Job.Step.ExecuteB\x08\n\x06\x61\x63tionB3Z1github.com/eolymp/go-sdk/eolymp/executor;executorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.executor.job_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/executor;executor'
  _JOB_ACTOR_ENVENTRY._options = None
  _JOB_ACTOR_ENVENTRY._serialized_options = b'8\001'
  _JOB_STEP_EXECUTE_ENVENTRY._options = None
  _JOB_STEP_EXECUTE_ENVENTRY._serialized_options = b'8\001'
  _JOB._serialized_start=75
  _JOB._serialized_end=2089
  _JOB_ACTOR._serialized_start=306
  _JOB_ACTOR._serialized_end=758
  _JOB_ACTOR_ENVENTRY._serialized_start=665
  _JOB_ACTOR_ENVENTRY._serialized_end=707
  _JOB_ACTOR_OUTPUTFORMAT._serialized_start=709
  _JOB_ACTOR_OUTPUTFORMAT._serialized_end=758
  _JOB_MOUNT._serialized_start=760
  _JOB_MOUNT._serialized_end=804
  _JOB_FILE._serialized_start=806
  _JOB_FILE._serialized_end=866
  _JOB_RUN._serialized_start=868
  _JOB_RUN._serialized_end=965
  _JOB_STEP._serialized_start=968
  _JOB_STEP._serialized_end=2089
  _JOB_STEP_WRITE._serialized_start=1294
  _JOB_STEP_WRITE._serialized_end=1402
  _JOB_STEP_UPLOAD._serialized_start=1405
  _JOB_STEP_UPLOAD._serialized_end=1573
  _JOB_STEP_COPY._serialized_start=1576
  _JOB_STEP_COPY._serialized_end=1711
  _JOB_STEP_EXECUTE._serialized_start=1714
  _JOB_STEP_EXECUTE._serialized_end=2016
  _JOB_STEP_EXECUTE_ENVENTRY._serialized_start=665
  _JOB_STEP_EXECUTE_ENVENTRY._serialized_end=707
  _JOB_STEP_GROUP._serialized_start=2018
  _JOB_STEP_GROUP._serialized_end=2079
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/membership_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.community import attribute_pb2 as eolymp_dot_community_dot_attribute__pb2
from eolymp.community import member_pb2 as eolymp_dot_community_dot_member__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)eolymp/community/membership_service.proto\x12\x10\x65olymp.community\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a eolymp/community/attribute.proto\x1a\x1d\x65olymp/community/member.proto\"\x19\n\x17\x44\x65scribeMembershipInput\"D\n\x18\x44\x65scribeMembershipOutput\x12(\n\x06member\x18\x01 \x01(\x0b\x32\x18.eolymp.community.Member\"N\n\x15UpdateMembershipInput\x12\x35\n\nattributes\x18\x01 \x03(\x0b\x32!.eolymp.community.Attribute.Value\"\x18\n\x16UpdateMembershipOutput2\xe0\x02\n\x11MembershipService\x12\x92\x01\n\x12\x44\x65scribeMembership\x12).eolymp.community.DescribeMembershipInput\x1a*.eolymp.community.DescribeMembershipOutput\"%\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x10\x12\x0e/members/_self\x12\xb5\x01\n\x10UpdateMembership\x12\'.eolymp.community.UpdateMembershipInput\x1a(.eolymp.community.UpdateMembershipOutput\"N\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1b\"\x19/members/_self/attributesB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.membership_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _MEMBERSHIPSERVICE.methods_by_name['DescribeMembership']._options = None
  _MEMBERSHIPSERVICE.methods_by_name['DescribeMembership']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\020\022\016/members/_self'
  _MEMBERSHIPSERVICE.methods_by_name['UpdateMembership']._options = None
  _MEMBERSHIPSERVICE.methods_by_name['UpdateMembership']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\033\"\031/members/_self/attributes'
  _DESCRIBEMEMBERSHIPINPUT._serialized_start=227
  _DESCRIBEMEMBERSHIPINPUT._serialized_end=252
  _DESCRIBEMEMBERSHIPOUTPUT._serialized_start=254
  _DESCRIBEMEMBERSHIPOUTPUT._serialized_end=322
  _UPDATEMEMBERSHIPINPUT._serialized_start=324
  _UPDATEMEMBERSHIPINPUT._serialized_end=402
  _UPDATEMEMBERSHIPOUTPUT._serialized_start=404
  _UPDATEMEMBERSHIPOUTPUT._serialized_end=428
  _MEMBERSHIPSERVICE._serialized_start=431
  _MEMBERSHIPSERVICE._serialized_end=783
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.course import student_pb2 as _student_pb2
from eolymp.wellknown import direction_pb2 as _direction_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateStudentInput(_message.Message):
    __slots__ = ["student"]
    STUDENT_FIELD_NUMBER: _ClassVar[int]
    student: _student_pb2.Student
    def __init__(self, student: _Optional[_Union[_student_pb2.Student, _Mapping]] = ...) -> None: ...

class CreateStudentOutput(_message.Message):
    __slots__ = ["student_id"]
    STUDENT_ID_FIELD_NUMBER: _ClassVar[int]
    student_id: str
    def __init__(self, student_id: _Optional[str] = ...) -> None: ...

class DeleteStudentInput(_message.Message):
    __slots__ = ["student_id"]
    STUDENT_ID_FIELD_NUMBER: _ClassVar[int]
    student_id: str
    def __init__(self, student_id: _Optional[str] = ...) -> None: ...

class DeleteStudentOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeStudentInput(_message.Message):
    __slots__ = ["student_id"]
    STUDENT_ID_FIELD_NUMBER: _ClassVar[int]
    student_id: str
    def __init__(self, student_id: _Optional[str] = ...) -> None: ...

class DescribeStudentOutput(_message.Message):
    __slots__ = ["student"]
    STUDENT_FIELD_NUMBER: _ClassVar[int]
    student: _student_pb2.Student
    def __init__(self, student: _Optional[_Union[_student_pb2.Student, _Mapping]] = ...) -> None: ...

class DescribeViewerInput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeViewerOutput(_message.Message):
    __slots__ = ["student"]
    STUDENT_FIELD_NUMBER: _ClassVar[int]
    student: _student_pb2.Student
    def __init__(self, student: _Optional[_Union[_student_pb2.Student, _Mapping]] = ...) -> None: ...

class ListStudentsInput(_message.Message):
    __slots__ = ["filters", "offset", "order", "size", "sort"]
    class Sortable(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Filter(_message.Message):
        __slots__ = ["id", "member_id", "name", "query", "status"]
        ID_FIELD_NUMBER: _ClassVar[int]
        MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        QUERY_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        member_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        name: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        query: str
        status: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        def __init__(self, query: _Optional[str] = ..., id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., member_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., name: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., status: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    COMPLETE_AT: ListStudentsInput.Sortable
    DEFAULT: ListStudentsInput.Sortable
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    NAME: ListStudentsInput.Sortable
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    STARTED_AT: ListStudentsInput.Sortable
    filters: ListStudentsInput.Filter
    offset: int
    order: _direction_pb2.Direction
    size: int
    sort: ListStudentsInput.Sortable
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListStudentsInput.Filter, _Mapping]] = ..., sort: _Optional[_Union[ListStudentsInput.Sortable, str]] = ..., order: _Optional[_Union[_direction_pb2.Direction, str]] = ...) -> None: ...

class ListStudentsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_student_pb2.Student]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_student_pb2.Student, _Mapping]]] = ...) -> None: ...

class StartCourseInput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class StartCourseOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateStudentInput(_message.Message):
    __slots__ = ["patch", "student", "student_id"]
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ALL: UpdateStudentInput.Patch
    BONUS_TIME: UpdateStudentInput.Patch
    PATCH_FIELD_NUMBER: _ClassVar[int]
    STUDENT_FIELD_NUMBER: _ClassVar[int]
    STUDENT_ID_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[UpdateStudentInput.Patch]
    student: _student_pb2.Student
    student_id: str
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateStudentInput.Patch, str]]] = ..., student_id: _Optional[str] = ..., student: _Optional[_Union[_student_pb2.Student, _Mapping]] = ...) -> None: ...

class UpdateStudentOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/worker/worker_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from eolymp.worker import job_pb2 as eolymp_dot_worker_dot_job__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/worker/worker_service.proto\x12\reolymp.worker\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a!eolymp/wellknown/expression.proto\x1a\x17\x65olymp/worker/job.proto\"\x88\x01\n\x0e\x43reateJobInput\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x39\n\x06inputs\x18\x02 \x03(\x0b\x32).eolymp.worker.CreateJobInput.InputsEntry\x1a-\n\x0bInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"!\n\x0f\x43reateJobOutput\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"\"\n\x10\x44\x65scribeJobInput\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"4\n\x11\x44\x65scribeJobOutput\x12\x1f\n\x03job\x18\x01 \x01(\x0b\x32\x12.eolymp.worker.Job\"\xfc\x01\n\rListJobsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x34\n\x07\x66ilters\x18( \x01(\x0b\x32#.eolymp.worker.ListJobsInput.Filter\x1a\x96\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12.\n\x04type\x18\x02 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x06status\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"B\n\x0eListJobsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12!\n\x05items\x18\x02 \x03(\x0b\x32\x12.eolymp.worker.Job2\x9a\x03\n\x06Worker\x12\x80\x01\n\tCreateJob\x12\x1d.eolymp.worker.CreateJobInput\x1a\x1e.eolymp.worker.CreateJobOutput\"4\x82\xe3\n\x14\x8a\xe3\n\x10worker:job:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x07\"\x05/jobs\x12\x8e\x01\n\x0b\x44\x65scribeJob\x12\x1f.eolymp.worker.DescribeJobInput\x1a .eolymp.worker.DescribeJobOutput\"<\x82\xe3\n\x13\x8a\xe3\n\x0fworker:job:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x10\x12\x0e/jobs/{job_id}\x12|\n\x08ListJobs\x12\x1c.eolymp.worker.ListJobsInput\x1a\x1d.eolymp.worker.ListJobsOutput\"3\x82\xe3\n\x13\x8a\xe3\n\x0fworker:job:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x07\x12\x05/jobs2\xa1\x03\n\rWorkerService\x12\x80\x01\n\tCreateJob\x12\x1d.eolymp.worker.CreateJobInput\x1a\x1e.eolymp.worker.CreateJobOutput\"4\x82\xe3\n\x14\x8a\xe3\n\x10worker:job:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x07\"\x05/jobs\x12\x8e\x01\n\x0b\x44\x65scribeJob\x12\x1f.eolymp.worker.DescribeJobInput\x1a .eolymp.worker.DescribeJobOutput\"<\x82\xe3\n\x13\x8a\xe3\n\x0fworker:job:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x10\x12\x0e/jobs/{job_id}\x12|\n\x08ListJobs\x12\x1c.eolymp.worker.ListJobsInput\x1a\x1d.eolymp.worker.ListJobsOutput\"3\x82\xe3\n\x13\x8a\xe3\n\x0fworker:job:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x07\x12\x05/jobsB/Z-github.com/eolymp/go-sdk/eolymp/worker;workerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.worker.worker_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/worker;worker'
  _CREATEJOBINPUT_INPUTSENTRY._options = None
  _CREATEJOBINPUT_INPUTSENTRY._serialized_options = b'8\001'
  _WORKER.methods_by_name['CreateJob']._options = None
  _WORKER.methods_by_name['CreateJob']._serialized_options = b'\202\343\n\024\212\343\n\020worker:job:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\007\"\005/jobs'
  _WORKER.methods_by_name['DescribeJob']._options = None
  _WORKER.methods_by_name['DescribeJob']._serialized_options = b'\202\343\n\023\212\343\n\017worker:job:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\020\022\016/jobs/{job_id}'
  _WORKER.methods_by_name['ListJobs']._options = None
  _WORKER.methods_by_name['ListJobs']._serialized_options = b'\202\343\n\023\212\343\n\017worker:job:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\007\022\005/jobs'
  _WORKERSERVICE.methods_by_name['CreateJob']._options = None
  _WORKERSERVICE.methods_by_name['CreateJob']._serialized_options = b'\202\343\n\024\212\343\n\020worker:job:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\007\"\005/jobs'
  _WORKERSERVICE.methods_by_name['DescribeJob']._options = None
  _WORKERSERVICE.methods_by_name['DescribeJob']._serialized_options = b'\202\343\n\023\212\343\n\017worker:job:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\020\022\016/jobs/{job_id}'
  _WORKERSERVICE.methods_by_name['ListJobs']._options = None
  _WORKERSERVICE.methods_by_name['ListJobs']._serialized_options = b'\202\343\n\023\212\343\n\017worker:job:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\007\022\005/jobs'
  _CREATEJOBINPUT._serialized_start=213
  _CREATEJOBINPUT._serialized_end=349
  _CREATEJOBINPUT_INPUTSENTRY._serialized_start=304
  _CREATEJOBINPUT_INPUTSENTRY._serialized_end=349
  _CREATEJOBOUTPUT._serialized_start=351
  _CREATEJOBOUTPUT._serialized_end=384
  _DESCRIBEJOBINPUT._serialized_start=386
  _DESCRIBEJOBINPUT._serialized_end=420
  _DESCRIBEJOBOUTPUT._serialized_start=422
  _DESCRIBEJOBOUTPUT._serialized_end=474
  _LISTJOBSINPUT._serialized_start=477
  _LISTJOBSINPUT._serialized_end=729
  _LISTJOBSINPUT_FILTER._serialized_start=579
  _LISTJOBSINPUT_FILTER._serialized_end=729
  _LISTJOBSOUTPUT._serialized_start=731
  _LISTJOBSOUTPUT._serialized_end=797
  _WORKER._serialized_start=800
  _WORKER._serialized_end=1210
  _WORKERSERVICE._serialized_start=1213
  _WORKERSERVICE._serialized_end=1630
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.harmony import agreement_pb2 as _agreement_pb2
from eolymp.harmony import consent_pb2 as _consent_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FollowShortcutInput(_message.Message):
    __slots__ = ["shortcut_id", "status"]
    SHORTCUT_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    shortcut_id: str
    status: _consent_pb2.Consent.Status
    def __init__(self, shortcut_id: _Optional[str] = ..., status: _Optional[_Union[_consent_pb2.Consent.Status, str]] = ...) -> None: ...

class FollowShortcutOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetConsentInput(_message.Message):
    __slots__ = ["agreement_id"]
    AGREEMENT_ID_FIELD_NUMBER: _ClassVar[int]
    agreement_id: str
    def __init__(self, agreement_id: _Optional[str] = ...) -> None: ...

class GetConsentOutput(_message.Message):
    __slots__ = ["consent"]
    CONSENT_FIELD_NUMBER: _ClassVar[int]
    consent: _consent_pb2.Consent
    def __init__(self, consent: _Optional[_Union[_consent_pb2.Consent, _Mapping]] = ...) -> None: ...

class ListAgreementsInput(_message.Message):
    __slots__ = ["preferred_locales"]
    PREFERRED_LOCALES_FIELD_NUMBER: _ClassVar[int]
    preferred_locales: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, preferred_locales: _Optional[_Iterable[str]] = ...) -> None: ...

class ListAgreementsOutput(_message.Message):
    __slots__ = ["items"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_agreement_pb2.Agreement]
    def __init__(self, items: _Optional[_Iterable[_Union[_agreement_pb2.Agreement, _Mapping]]] = ...) -> None: ...

class SetConsentInput(_message.Message):
    __slots__ = ["agreement_id", "status"]
    AGREEMENT_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    agreement_id: str
    status: _consent_pb2.Consent.Status
    def __init__(self, agreement_id: _Optional[str] = ..., status: _Optional[_Union[_consent_pb2.Consent.Status, str]] = ...) -> None: ...

class SetConsentOutput(_message.Message):
    __slots__ = ["consent"]
    CONSENT_FIELD_NUMBER: _ClassVar[int]
    consent: _consent_pb2.Consent
    def __init__(self, consent: _Optional[_Union[_consent_pb2.Consent, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/entry_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.course import entry_pb2 as eolymp_dot_course_dot_entry__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!eolymp/course/entry_service.proto\x12\reolymp.course\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x19\x65olymp/course/entry.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"7\n\x10\x43reateEntryInput\x12#\n\x05\x65ntry\x18\x01 \x01(\x0b\x32\x14.eolymp.course.Entry\"%\n\x11\x43reateEntryOutput\x12\x10\n\x08\x65ntry_id\x18\x01 \x01(\t\"\xa0\x02\n\x10UpdateEntryInput\x12\x34\n\x05patch\x18\x01 \x03(\x0e\x32%.eolymp.course.UpdateEntryInput.Patch\x12\x10\n\x08\x65ntry_id\x18\x02 \x01(\t\x12#\n\x05\x65ntry\x18\x03 \x01(\x0b\x32\x14.eolymp.course.Entry\"\x9e\x01\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\t\n\x05TITLE\x10\x01\x12\t\n\x05\x44RAFT\x10\x02\x12\x0f\n\x0b\x43ONTENT_ALL\x10\x03\x12\x11\n\rSECTION_IMAGE\x10\n\x12\x17\n\x13SECTION_DESCRIPTION\x10\x0b\x12\x13\n\x0fVIDEO_IMAGE_URL\x10\x14\x12\x13\n\x0fVIDEO_VIDEO_URL\x10\x15\x12\x0f\n\x0bPROBLEM_URL\x10\x1e\"\x13\n\x11UpdateEntryOutput\"3\n\x10RenameEntryInput\x12\x10\n\x08\x65ntry_id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\"\x13\n\x11RenameEntryOutput\"D\n\x0eMoveEntryInput\x12\x10\n\x08\x65ntry_id\x18\x01 \x01(\t\x12\x11\n\tparent_id\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\r\"\x11\n\x0fMoveEntryOutput\"$\n\x10\x44\x65leteEntryInput\x12\x10\n\x08\x65ntry_id\x18\x01 \x01(\t\"\x13\n\x11\x44\x65leteEntryOutput\"6\n\x12\x44\x65scribeEntryInput\x12\x10\n\x08\x65ntry_id\x18\x01 \x01(\t\x12\x0e\n\x06render\x18\x02 \x01(\x08\":\n\x13\x44\x65scribeEntryOutput\x12#\n\x05\x65ntry\x18\x01 \x01(\x0b\x32\x14.eolymp.course.Entry\"\xd3\x03\n\x10ListEntriesInput\x12\x0e\n\x06render\x18\x01 \x01(\x08\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x37\n\x07\x66ilters\x18( \x01(\x0b\x32&.eolymp.course.ListEntriesInput.Filter\x12\x36\n\x04sort\x18\x32 \x01(\x0e\x32(.eolymp.course.ListEntriesInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x1a\xda\x01\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\n \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tparent_id\x18\x0b \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x05\x64raft\x18\x0c \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x31\n\x05title\x18\r \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"\x17\n\x08Sortable\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\"G\n\x11ListEntriesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12#\n\x05items\x18\x02 \x03(\x0b\x32\x14.eolymp.course.Entry\"A\n\x10\x44\x65scribeTOCInput\x12\x0f\n\x07root_id\x18\x01 \x01(\t\x12\r\n\x05\x64\x65pth\x18\x02 \x01(\r\x12\r\n\x05\x64raft\x18\x03 \x01(\x08\"8\n\x11\x44\x65scribeTOCOutput\x12#\n\x05items\x18\x02 \x03(\x0b\x32\x14.eolymp.course.Entry\"$\n\x10ListParentsInput\x12\x10\n\x08\x65ntry_id\x18\x01 \x01(\t\"8\n\x11ListParentsOutput\x12#\n\x05items\x18\x02 \x03(\x0b\x32\x14.eolymp.course.Entry\")\n\x15\x44\x65scribeProgressInput\x12\x10\n\x08\x65ntry_id\x18\x01 \x01(\t\"*\n\x16\x44\x65scribeProgressOutput\x12\x10\n\x08progress\x18\x01 \x01(\x02\"9\n\x13ReportProgressInput\x12\x10\n\x08\x65ntry_id\x18\x01 \x01(\t\x12\x10\n\x08progress\x18\x02 \x01(\x02\"\x16\n\x14ReportProgressOutput2\xc2\r\n\x0c\x45ntryService\x12\x8c\x01\n\x0b\x43reateEntry\x12\x1f.eolymp.course.CreateEntryInput\x1a .eolymp.course.CreateEntryOutput\":\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\n\"\x08/entries\x12\x97\x01\n\x0bUpdateEntry\x12\x1f.eolymp.course.UpdateEntryInput\x1a .eolymp.course.UpdateEntryOutput\"E\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x15\x1a\x13/entries/{entry_id}\x12\x9d\x01\n\x0bRenameEntry\x12\x1f.eolymp.course.RenameEntryInput\x1a .eolymp.course.RenameEntryOutput\"K\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x1b\x1a\x19/entries/{entry_id}/title\x12\x9a\x01\n\tMoveEntry\x12\x1d.eolymp.course.MoveEntryInput\x1a\x1e.eolymp.course.MoveEntryOutput\"N\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x1e\x1a\x1c/entries/{entry_id}/position\x12\x97\x01\n\x0b\x44\x65leteEntry\x12\x1f.eolymp.course.DeleteEntryInput\x1a .eolymp.course.DeleteEntryOutput\"E\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x15*\x13/entries/{entry_id}\x12\x9c\x01\n\rDescribeEntry\x12!.eolymp.course.DescribeEntryInput\x1a\".eolymp.course.DescribeEntryOutput\"D\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x15\x12\x13/entries/{entry_id}\x12\x8b\x01\n\x0bListEntries\x12\x1f.eolymp.course.ListEntriesInput\x1a .eolymp.course.ListEntriesOutput\"9\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\n\x12\x08/entries\x12\x87\x01\n\x0b\x44\x65scribeTOC\x12\x1f.eolymp.course.DescribeTOCInput\x1a .eolymp.course.DescribeTOCOutput\"5\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x06\x12\x04/toc\x12\x9e\x01\n\x0bListParents\x12\x1f.eolymp.course.ListParentsInput\x1a .eolymp.course.ListParentsOutput\"L\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x1d\x12\x1b/entries/{entry_id}/parents\x12\xae\x01\n\x10\x44\x65scribeProgress\x12$.eolymp.course.DescribeProgressInput\x1a%.eolymp.course.DescribeProgressOutput\"M\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x1e\x12\x1c/entries/{entry_id}/progress\x12\xa8\x01\n\x0eReportProgress\x12\".eolymp.course.ReportProgressInput\x1a#.eolymp.course.ReportProgressOutput\"M\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x1e\x1a\x1c/entries/{entry_id}/progressB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.entry_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _ENTRYSERVICE.methods_by_name['CreateEntry']._options = None
  _ENTRYSERVICE.methods_by_name['CreateEntry']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\n\"\010/entries'
  _ENTRYSERVICE.methods_by_name['UpdateEntry']._options = None
  _ENTRYSERVICE.methods_by_name['UpdateEntry']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\025\032\023/entries/{entry_id}'
  _ENTRYSERVICE.methods_by_name['RenameEntry']._options = None
  _ENTRYSERVICE.methods_by_name['RenameEntry']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\033\032\031/entries/{entry_id}/title'
  _ENTRYSERVICE.methods_by_name['MoveEntry']._options = None
  _ENTRYSERVICE.methods_by_name['MoveEntry']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\036\032\034/entries/{entry_id}/position'
  _ENTRYSERVICE.methods_by_name['DeleteEntry']._options = None
  _ENTRYSERVICE.methods_by_name['DeleteEntry']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\025*\023/entries/{entry_id}'
  _ENTRYSERVICE.methods_by_name['DescribeEntry']._options = None
  _ENTRYSERVICE.methods_by_name['DescribeEntry']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\025\022\023/entries/{entry_id}'
  _ENTRYSERVICE.methods_by_name['ListEntries']._options = None
  _ENTRYSERVICE.methods_by_name['ListEntries']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\n\022\010/entries'
  _ENTRYSERVICE.methods_by_name['DescribeTOC']._options = None
  _ENTRYSERVICE.methods_by_name['DescribeTOC']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\n\202\323\344\223\002\006\022\004/toc'
  _ENTRYSERVICE.methods_by_name['ListParents']._options = None
  _ENTRYSERVICE.methods_by_name['ListParents']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\n\202\323\344\223\002\035\022\033/entries/{entry_id}/parents'
  _ENTRYSERVICE.methods_by_name['DescribeProgress']._options = None
  _ENTRYSERVICE.methods_by_name['DescribeProgress']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\n\202\323\344\223\002\036\022\034/entries/{entry_id}/progress'
  _ENTRYSERVICE.methods_by_name['ReportProgress']._options = None
  _ENTRYSERVICE.methods_by_name['ReportProgress']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\n\202\323\344\223\002\036\032\034/entries/{entry_id}/progress'
  _CREATEENTRYINPUT._serialized_start=247
  _CREATEENTRYINPUT._serialized_end=302
  _CREATEENTRYOUTPUT._serialized_start=304
  _CREATEENTRYOUTPUT._serialized_end=341
  _UPDATEENTRYINPUT._serialized_start=344
  _UPDATEENTRYINPUT._serialized_end=632
  _UPDATEENTRYINPUT_PATCH._serialized_start=474
  _UPDATEENTRYINPUT_PATCH._serialized_end=632
  _UPDATEENTRYOUTPUT._serialized_start=634
  _UPDATEENTRYOUTPUT._serialized_end=653
  _RENAMEENTRYINPUT._serialized_start=655
  _RENAMEENTRYINPUT._serialized_end=706
  _RENAMEENTRYOUTPUT._serialized_start=708
  _RENAMEENTRYOUTPUT._serialized_end=727
  _MOVEENTRYINPUT._serialized_start=729
  _MOVEENTRYINPUT._serialized_end=797
  _MOVEENTRYOUTPUT._serialized_start=799
  _MOVEENTRYOUTPUT._serialized_end=816
  _DELETEENTRYINPUT._serialized_start=818
  _DELETEENTRYINPUT._serialized_end=854
  _DELETEENTRYOUTPUT._serialized_start=856
  _DELETEENTRYOUTPUT._serialized_end=875
  _DESCRIBEENTRYINPUT._serialized_start=877
  _DESCRIBEENTRYINPUT._serialized_end=931
  _DESCRIBEENTRYOUTPUT._serialized_start=933
  _DESCRIBEENTRYOUTPUT._serialized_end=991
  _LISTENTRIESINPUT._serialized_start=994
  _LISTENTRIESINPUT._serialized_end=1461
  _LISTENTRIESINPUT_FILTER._serialized_start=1218
  _LISTENTRIESINPUT_FILTER._serialized_end=1436
  _LISTENTRIESINPUT_SORTABLE._serialized_start=1438
  _LISTENTRIESINPUT_SORTABLE._serialized_end=1461
  _LISTENTRIESOUTPUT._serialized_start=1463
  _LISTENTRIESOUTPUT._serialized_end=1534
  _DESCRIBETOCINPUT._serialized_start=1536
  _DESCRIBETOCINPUT._serialized_end=1601
  _DESCRIBETOCOUTPUT._serialized_start=1603
  _DESCRIBETOCOUTPUT._serialized_end=1659
  _LISTPARENTSINPUT._serialized_start=1661
  _LISTPARENTSINPUT._serialized_end=1697
  _LISTPARENTSOUTPUT._serialized_start=1699
  _LISTPARENTSOUTPUT._serialized_end=1755
  _DESCRIBEPROGRESSINPUT._serialized_start=1757
  _DESCRIBEPROGRESSINPUT._serialized_end=1798
  _DESCRIBEPROGRESSOUTPUT._serialized_start=1800
  _DESCRIBEPROGRESSOUTPUT._serialized_end=1842
  _REPORTPROGRESSINPUT._serialized_start=1844
  _REPORTPROGRESSINPUT._serialized_end=1901
  _REPORTPROGRESSOUTPUT._serialized_start=1903
  _REPORTPROGRESSOUTPUT._serialized_end=1925
  _ENTRYSERVICE._serialized_start=1928
  _ENTRYSERVICE._serialized_end=3658
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Space(_message.Message):
    __slots__ = ["home_url", "id", "image", "issuer_url", "key", "name", "plan", "type", "url", "visibility"]
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Visibility(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Quota(_message.Message):
        __slots__ = ["active_contests_per_space", "attributes_per_space", "contests_per_space", "courses_per_space", "members_per_space", "participants_per_contest", "permissions_per_space", "problems_per_contest", "problems_per_space", "scoreboards_per_space"]
        ACTIVE_CONTESTS_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
        ATTRIBUTES_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
        CONTESTS_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
        COURSES_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
        MEMBERS_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
        PARTICIPANTS_PER_CONTEST_FIELD_NUMBER: _ClassVar[int]
        PERMISSIONS_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
        PROBLEMS_PER_CONTEST_FIELD_NUMBER: _ClassVar[int]
        PROBLEMS_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
        SCOREBOARDS_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
        active_contests_per_space: int
        attributes_per_space: int
        contests_per_space: int
        courses_per_space: int
        members_per_space: int
        participants_per_contest: int
        permissions_per_space: int
        problems_per_contest: int
        problems_per_space: int
        scoreboards_per_space: int
        def __init__(self, problems_per_space: _Optional[int] = ..., members_per_space: _Optional[int] = ..., contests_per_space: _Optional[int] = ..., active_contests_per_space: _Optional[int] = ..., scoreboards_per_space: _Optional[int] = ..., permissions_per_space: _Optional[int] = ..., attributes_per_space: _Optional[int] = ..., courses_per_space: _Optional[int] = ..., problems_per_contest: _Optional[int] = ..., participants_per_contest: _Optional[int] = ...) -> None: ...
    CLASSROOM: Space.Type
    COMPETITION: Space.Type
    HOME_URL_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    IMAGE_FIELD_NUMBER: _ClassVar[int]
    ISSUER_URL_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OTHER: Space.Type
    PLAN_FIELD_NUMBER: _ClassVar[int]
    PRIVATE: Space.Visibility
    PUBLIC: Space.Visibility
    TEAMROOM: Space.Type
    TYPE_FIELD_NUMBER: _ClassVar[int]
    UNKNOWN_TYPE: Space.Type
    UNKNOWN_VISIBILITY: Space.Visibility
    URL_FIELD_NUMBER: _ClassVar[int]
    VISIBILITY_FIELD_NUMBER: _ClassVar[int]
    home_url: str
    id: str
    image: str
    issuer_url: str
    key: str
    name: str
    plan: str
    type: Space.Type
    url: str
    visibility: Space.Visibility
    def __init__(self, id: _Optional[str] = ..., key: _Optional[str] = ..., url: _Optional[str] = ..., name: _Optional[str] = ..., image: _Optional[str] = ..., type: _Optional[_Union[Space.Type, str]] = ..., plan: _Optional[str] = ..., visibility: _Optional[_Union[Space.Visibility, str]] = ..., home_url: _Optional[str] = ..., issuer_url: _Optional[str] = ...) -> None: ...
